@@ -51,6 +51,7 @@ from .type_defs import (
     GetInfrastructureConfigurationResponseTypeDef,
     ImageTestsConfigurationTypeDef,
     ImportComponentResponseTypeDef,
+    ImportVmImageResponseTypeDef,
     InstanceBlockDeviceMappingTypeDef,
     InstanceConfigurationTypeDef,
     InstanceMetadataOptionsTypeDef,
@@ -119,7 +120,7 @@ class Exceptions:
 
 class imagebuilderClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html)
     """
 
@@ -135,7 +136,7 @@ class imagebuilderClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#can_paginate)
         """
 
@@ -145,7 +146,7 @@ class imagebuilderClient(BaseClient):
         """
         CancelImageCreation cancels the creation of Image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.cancel_image_creation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#cancel_image_creation)
         """
 
@@ -168,7 +169,7 @@ class imagebuilderClient(BaseClient):
         Creates a new component that can be used to build, validate, test, and assess
         your image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_component)
         """
 
@@ -195,7 +196,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_container_recipe)
         """
 
@@ -211,7 +212,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_distribution_configuration)
         """
 
@@ -230,7 +231,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image)
         """
 
@@ -253,7 +254,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_pipeline)
         """
 
@@ -274,7 +275,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_image_recipe)
         """
 
@@ -299,7 +300,7 @@ class imagebuilderClient(BaseClient):
         """
         Creates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.create_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#create_infrastructure_configuration)
         """
 
@@ -307,7 +308,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a component build version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_component)
         """
 
@@ -317,7 +318,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_container_recipe)
         """
 
@@ -327,7 +328,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_distribution_configuration)
         """
 
@@ -335,7 +336,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an Image Builder image resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image)
         """
 
@@ -343,7 +344,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_pipeline)
         """
 
@@ -351,7 +352,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_image_recipe)
         """
 
@@ -361,7 +362,7 @@ class imagebuilderClient(BaseClient):
         """
         Deletes an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.delete_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#delete_infrastructure_configuration)
         """
 
@@ -375,7 +376,7 @@ class imagebuilderClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#generate_presigned_url)
         """
 
@@ -383,7 +384,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a component object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component)
         """
 
@@ -391,7 +392,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a component policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_component_policy)
         """
 
@@ -399,7 +400,7 @@ class imagebuilderClient(BaseClient):
         """
         Retrieves a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe)
         """
 
@@ -409,7 +410,7 @@ class imagebuilderClient(BaseClient):
         """
         Retrieves the policy for a container recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_container_recipe_policy)
         """
 
@@ -419,7 +420,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets a distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_distribution_configuration)
         """
 
@@ -427,7 +428,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image)
         """
 
@@ -435,7 +436,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_pipeline)
         """
 
@@ -443,7 +444,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_policy)
         """
 
@@ -451,7 +452,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe)
         """
 
@@ -461,7 +462,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an image recipe policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_image_recipe_policy)
         """
 
@@ -471,7 +472,7 @@ class imagebuilderClient(BaseClient):
         """
         Gets an infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.get_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#get_infrastructure_configuration)
         """
 
@@ -494,17 +495,38 @@ class imagebuilderClient(BaseClient):
         """
         Imports a component and transforms its data into a component document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.import_component)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#import_component)
         """
 
+    def import_vm_image(
+        self,
+        *,
+        name: str,
+        semanticVersion: str,
+        platform: PlatformType,
+        vmImportTaskId: str,
+        clientToken: str,
+        description: str = ...,
+        osVersion: str = ...,
+        tags: Mapping[str, str] = ...
+    ) -> ImportVmImageResponseTypeDef:
+        """
+        When you export your virtual machine (VM) from its virtualization environment,
+        that process creates a set of one or more disk container files that act as
+        snapshots of your VM’s environment, settings, and data.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.import_vm_image)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#import_vm_image)
+        """
+
     def list_component_build_versions(
         self, *, componentVersionArn: str, maxResults: int = ..., nextToken: str = ...
     ) -> ListComponentBuildVersionsResponseTypeDef:
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_component_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_component_build_versions)
         """
 
@@ -520,7 +542,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of component build versions for the specified semantic version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_components)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_components)
         """
 
@@ -535,7 +557,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of container recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_container_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_container_recipes)
         """
 
@@ -549,7 +571,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of distribution configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_distribution_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_distribution_configurations)
         """
 
@@ -564,7 +586,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image build versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_image_build_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_build_versions)
         """
 
@@ -575,7 +597,7 @@ class imagebuilderClient(BaseClient):
         List the Packages that are associated with an Image Build Version, as determined
         by Amazon Web Services Systems Manager Inventory at build time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_image_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_packages)
         """
 
@@ -590,7 +612,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of images created by the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipeline_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipeline_images)
         """
 
@@ -604,7 +626,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_image_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_pipelines)
         """
 
@@ -619,7 +641,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of image recipes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_image_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_image_recipes)
         """
 
@@ -636,7 +658,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of images that you have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_images)
         """
 
@@ -650,7 +672,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns a list of infrastructure configurations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_infrastructure_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_infrastructure_configurations)
         """
 
@@ -658,7 +680,7 @@ class imagebuilderClient(BaseClient):
         """
         Returns the list of tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#list_tags_for_resource)
         """
 
@@ -668,7 +690,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to a component.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.put_component_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_component_policy)
         """
 
@@ -678,7 +700,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to a container image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.put_container_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_container_recipe_policy)
         """
 
@@ -686,7 +708,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.put_image_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_policy)
         """
 
@@ -696,7 +718,7 @@ class imagebuilderClient(BaseClient):
         """
         Applies a policy to an image recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.put_image_recipe_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#put_image_recipe_policy)
         """
 
@@ -706,7 +728,7 @@ class imagebuilderClient(BaseClient):
         """
         Manually triggers a pipeline to create an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.start_image_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#start_image_pipeline_execution)
         """
 
@@ -714,7 +736,7 @@ class imagebuilderClient(BaseClient):
         """
         Adds a tag to a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#tag_resource)
         """
 
@@ -722,7 +744,7 @@ class imagebuilderClient(BaseClient):
         """
         Removes a tag from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#untag_resource)
         """
 
@@ -737,7 +759,7 @@ class imagebuilderClient(BaseClient):
         """
         Updates a new distribution configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.update_distribution_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_distribution_configuration)
         """
 
@@ -759,7 +781,7 @@ class imagebuilderClient(BaseClient):
         """
         Updates an image pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.update_image_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_image_pipeline)
         """
 
@@ -783,6 +805,6 @@ class imagebuilderClient(BaseClient):
         """
         Updates a new infrastructure configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.13/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/imagebuilder.html#imagebuilder.Client.update_infrastructure_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/client.html#update_infrastructure_configuration)
         """
